@@ -22,12 +22,11 @@
 #	include <stdexcept>
 #endif
 
-#ifdef __MINGW32__
-#	include <io.h> // for unlink in C++0x mode
-#endif
-
-#if defined(__CELLOS_LV2__) || defined(ANDROID) || defined(_GLIBCXX_HAVE_UNISTD_H) || defined(__APPLE__)
-#	include <unistd.h> // for unlink
+// for unlink
+#ifdef _WIN32
+#	include <io.h>
+#else
+#	include <unistd.h>
 #endif
 
 using namespace pugi;
@@ -590,13 +589,12 @@ TEST(document_load_file_wide_out_of_memory)
 	CHECK(result.status == status_out_of_memory || result.status == status_file_not_found);
 }
 
-#if defined(__linux__) || defined(__APPLE__)
+#if defined(__APPLE__)
 TEST(document_load_file_special_folder)
 {
 	xml_document doc;
 	xml_parse_result result = doc.load_file(".");
-	// status_out_of_memory is somewhat counter-intuitive but on Linux ftell returns LONG_MAX for directories
-	CHECK(result.status == status_file_not_found || result.status == status_io_error || result.status == status_out_of_memory);
+	CHECK(result.status == status_io_error);
 }
 #endif
 
@@ -1807,4 +1805,15 @@ TEST(document_move_compact_fail)
 	CHECK(!docs[safe_count+1].first_child());
 }
 #endif
+
+TEST(document_move_assign_empty)
+{
+	xml_document doc;
+	doc.append_child(STR("node"));
+
+	doc = xml_document();
+	doc.append_child(STR("node2"));
+
+	CHECK_NODE(doc, STR("<node2/>"));
+}
 #endif
