@@ -2,13 +2,15 @@
 
 #include <string.h> // because Borland's STL is braindead, we have to include <string.h> _before_ <string> in order to get memcmp
 
-#include "common.hpp"
+#include "test.hpp"
 
 #include "helpers.hpp"
 
 #include <string>
 #include <vector>
 
+using namespace pugi;
+
 TEST_XML(xpath_api_select_nodes, "<node><head/><foo/><foo/><tail/></node>")
 {
 	xpath_node_set ns1 = doc.select_nodes(STR("node/foo"));
@@ -107,6 +109,7 @@ TEST_XML(xpath_api_nodeset_accessors, "<node><foo/><foo/></node>")
 
 TEST_XML(xpath_api_nodeset_copy, "<node><foo/><foo/></node>")
 {
+	xpath_node_set empty;
 	xpath_node_set set = doc.select_nodes(STR("node/foo"));
 
 	xpath_node_set copy1 = set;
@@ -120,7 +123,7 @@ TEST_XML(xpath_api_nodeset_copy, "<node><foo/><foo/></node>")
 
 	xpath_node_set copy3;
 	copy3 = set;
-	copy3 = copy3;
+	copy3 = xpath_node_set(copy3);
 	CHECK(copy3.size() == 2);
 	CHECK_STRING(copy3[0].node().name(), STR("foo"));
 
@@ -132,7 +135,7 @@ TEST_XML(xpath_api_nodeset_copy, "<node><foo/><foo/></node>")
 
 	xpath_node_set copy5;
 	copy5 = set;
-	copy5 = xpath_node_set();
+	copy5 = empty;
 	CHECK(copy5.size() == 0);
 }
 
@@ -398,17 +401,6 @@ TEST_XML(xpath_api_node_set_assign_out_of_memory_preserve, "<node><a/><b/></node
 	CHECK(ns[0] == doc.child(STR("node")).child(STR("a")) && ns[1] == doc.child(STR("node")).child(STR("b")));
 }
 
-TEST_XML(xpath_api_deprecated_select_single_node, "<node><head/><foo id='1'/><foo/><tail/></node>")
-{
-	xpath_node n1 = doc.select_single_node(STR("node/foo"));
-
-	xpath_query q(STR("node/foo"));
-	xpath_node n2 = doc.select_single_node(q);
-
-	CHECK(n1.node().attribute(STR("id")).as_int() == 1);
-	CHECK(n2.node().attribute(STR("id")).as_int() == 1);
-}
-
 TEST(xpath_api_empty)
 {
 	xml_node c;
@@ -572,6 +564,18 @@ TEST(xpath_api_nodeset_move_assign_empty)
 	CHECK(move.type() == xpath_node_set::type_sorted);
 }
 
+TEST_XML(xpath_api_nodeset_move_assign_self, "<node><foo/><foo/><bar/></node>")
+{
+	xpath_node_set set = doc.select_nodes(STR("node/bar"));
+
+	CHECK(set.size() == 1);
+	CHECK(set.type() == xpath_node_set::type_sorted);
+
+	test_runner::_memory_fail_threshold = 1;
+
+	set = std::move(*&set);
+}
+
 TEST(xpath_api_query_move)
 {
 	xml_node c;
